@@ -1,22 +1,16 @@
-/* Copyright (C) 1989, 1990, 1991 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-
-/*$Id: gdevdjtc.c,v 1.3.2.1.2.1 2003/01/17 00:49:00 giles Exp $*/
+/* $Id: gdevdjtc.c 6651 2006-03-13 16:18:19Z stefan $*/
 /* HP DeskJet 500C driver */
 #include "gdevprn.h"
 #include "gdevpcl.h"
@@ -56,9 +50,9 @@ const gx_device_printer far_data gs_djet500c_device =
     3, djet500c_print_page);
 
 /* Forward references */
-private int djet500c_print_page(P2(gx_device_printer *, FILE *));
+private int djet500c_print_page(gx_device_printer *, FILE *);
 
-static int mode2compress(P3(byte *row, byte *end_row, byte *compressed));
+static int mode2compress(byte *row, byte *end_row, byte *compressed);
 
 /* The DeskJet 500C uses additive colors in separate planes. */
 /* We only keep one bit of color, with 1 = R, 2 = G, 4 = B. */
