@@ -1,22 +1,16 @@
-/* Copyright (C) 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-
-/*$Id: gdevl31s.c,v 1.2.6.1.2.1 2003/01/17 00:49:00 giles Exp $ */
+/* $Id: gdevl31s.c 6651 2006-03-13 16:18:19Z stefan $ */
 /*
  * H-P LaserJet 3100 driver
  *
@@ -180,7 +174,8 @@ lj3100sw_print_page_copies(gx_device_printer *pdev, FILE *prn_stream, int num_co
 	int paper_height = pdev->height;
 	int paper_width  = pdev->width;
 	int line_size = gdev_prn_raster(pdev);
-	byte *in = (byte *)gs_malloc(line_size, 1, "lj3100sw_print_page");
+	gs_memory_t *mem = pdev->memory;
+	byte *in = (byte *)gs_malloc(mem, line_size, 1, "lj3100sw_print_page");
 	byte *data;
 	if (in == 0)
 		return_error(gs_error_VMerror);
@@ -263,7 +258,7 @@ lj3100sw_print_page_copies(gx_device_printer *pdev, FILE *prn_stream, int num_co
 	for (i = 0; i < 4 * ppdev->NumCopies; i++)
 		lj3100sw_output_section_header(prn_stream, 54, 0, 0);
 
-	gs_free((char *)in, line_size, 1, "lj3100sw_print_page");
+	gs_free(mem, (char *)in, line_size, 1, "lj3100sw_print_page");
 	return 0;
 }
 
