@@ -1,22 +1,16 @@
-/* Copyright (C) 1989, 1992, 1993, 1994, 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-
-/*$Id: gdevmswn.h,v 1.2.6.1.2.1 2003/01/17 00:49:01 giles Exp $ */
+/* $Id: gdevmswn.h 6651 2006-03-13 16:18:19Z stefan $ */
 /* Shared definitions for Microsoft Windows 3.n drivers */
 
 #ifndef gdevmswn_INCLUDED
@@ -24,7 +18,6 @@
 
 #include "string_.h"
 #include <stdlib.h>
-#include "dos_.h"
 #include "gx.h"
 #include "gserrors.h"
 #include "gxdevice.h"
@@ -37,9 +30,9 @@
 typedef struct gx_device_win_s gx_device_win;
 
 /* Utility routines in gdevmswn.c */
-LPLOGPALETTE win_makepalette(P1(gx_device_win *));
-int win_nomemory(P0());
-void win_update(P1(gx_device_win *));
+LPLOGPALETTE win_makepalette(gx_device_win *);
+int win_nomemory(void);
+void win_update(gx_device_win *);
 
 /* Device procedures shared by all implementations. */
 /* Implementations may wrap their own code around _open and _close. */
@@ -57,16 +50,16 @@ dev_proc_get_alpha_bits(win_get_alpha_bits);
 /* Common part of the device descriptor. */
 
 #define win_proc_copy_to_clipboard(proc)\
-  void proc(P1(gx_device_win *))
+  void proc(gx_device_win *)
 
 #define win_proc_repaint(proc)\
-  void proc(P8(gx_device_win *, HDC, int, int, int, int, int, int))
+  void proc(gx_device_win *, HDC, int, int, int, int, int, int)
 
 #define win_proc_alloc_bitmap(proc)\
-  int proc(P2(gx_device_win *, gx_device *))
+  int proc(gx_device_win *, gx_device *)
 
 #define win_proc_free_bitmap(proc)\
-  void proc(P1(gx_device_win *))
+  void proc(gx_device_win *)
 
 #define win_gsview_sizeof 80
 
@@ -89,8 +82,8 @@ struct gx_device_win_s {
 
 /* Initial values for width and height */
 #define INITIAL_RESOLUTION 96.0
-#define INITIAL_WIDTH (INITIAL_RESOLUTION * 85 / 10 + 1)
-#define INITIAL_HEIGHT (INITIAL_RESOLUTION * 11 + 1)
+#define INITIAL_WIDTH (int)(INITIAL_RESOLUTION * 85 / 10 + 0.5)
+#define INITIAL_HEIGHT (int)(INITIAL_RESOLUTION * 11 + 0.5)
 
 /* A macro for casting the device argument */
 #define wdev ((gx_device_win *)dev)
