@@ -1,22 +1,17 @@
-/* Copyright (C) 1991, 1992 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevpjet.c,v 1.3.2.1.2.1 2003/01/17 00:49:01 giles Exp $*/
+/* $Id: gdevpjet.c 6651 2006-03-13 16:18:19Z stefan $*/
 /* H-P PaintJet, PaintJet XL, and DEC LJ250 drivers. */
 /* Thanks to Rob Reiss (rob@moray.berkeley.edu) for the PaintJet XL */
 /* modifications. */
@@ -35,7 +30,7 @@
 private dev_proc_print_page(lj250_print_page);
 private dev_proc_print_page(paintjet_print_page);
 private dev_proc_print_page(pjetxl_print_page);
-private int pj_common_print_page(P4(gx_device_printer *, FILE *, int, const char *));
+private int pj_common_print_page(gx_device_printer *, FILE *, int, const char *);
 private gx_device_procs paintjet_procs =
   prn_color_procs(gdev_prn_open, gdev_prn_output_page, gdev_prn_close,
     gdev_pcl_3bit_map_rgb_color, gdev_pcl_3bit_map_color_rgb);
@@ -65,7 +60,7 @@ const gx_device_printer far_data gs_pjetxl_device =
 	3, pjetxl_print_page);
 
 /* Forward references */
-private int compress1_row(P3(const byte *, const byte *, byte *));
+private int compress1_row(const byte *, const byte *, byte *);
 
 /* ------ Internal routines ------ */
 
@@ -104,17 +99,17 @@ pj_common_print_page(gx_device_printer *pdev, FILE *prn_stream, int y_origin,
 {
 #define DATA_SIZE (LINE_SIZE * 8)
 	byte *data =
-		(byte *)gs_malloc(DATA_SIZE, 1,
+	        (byte *)gs_malloc(pdev->memory, DATA_SIZE, 1,
 				  "paintjet_print_page(data)");
 	byte *plane_data =
-		(byte *)gs_malloc(LINE_SIZE * 3, 1,
+		(byte *)gs_malloc(pdev->memory, LINE_SIZE * 3, 1,
 				  "paintjet_print_page(plane_data)");
 	if ( data == 0 || plane_data == 0 )
 	{	if ( data )
-			gs_free((char *)data, DATA_SIZE, 1,
+			gs_free(pdev->memory, (char *)data, DATA_SIZE, 1,
 				"paintjet_print_page(data)");
 		if ( plane_data )
-			gs_free((char *)plane_data, LINE_SIZE * 3, 1,
+			gs_free(pdev->memory, (char *)plane_data, LINE_SIZE * 3, 1,
 				"paintjet_print_page(plane_data)");
 		return_error(gs_error_VMerror);
 	}
@@ -212,8 +207,8 @@ pj_common_print_page(gx_device_printer *pdev, FILE *prn_stream, int y_origin,
 	/* end the page */
 	fputs(end_page, prn_stream);
 
-	gs_free((char *)data, DATA_SIZE, 1, "paintjet_print_page(data)");
-	gs_free((char *)plane_data, LINE_SIZE * 3, 1, "paintjet_print_page(plane_data)");
+	gs_free(pdev->memory, (char *)data, DATA_SIZE, 1, "paintjet_print_page(data)");
+	gs_free(pdev->memory, (char *)plane_data, LINE_SIZE * 3, 1, "paintjet_print_page(plane_data)");
 
 	return 0;
 }
