@@ -1,22 +1,17 @@
-/* Copyright (C) 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevplnx.c,v 1.2.6.1.2.1 2003/01/17 00:49:01 giles Exp $*/
+/* $Id: gdevplnx.c 6651 2006-03-13 16:18:19Z stefan $*/
 /* Plane extraction device */
 #include "gx.h"
 #include "gserrors.h"
@@ -160,7 +155,7 @@ reduce_drawing_color(gx_device_color *ppdc, gx_device_plane_extract *edev,
     if (gx_dc_is_pure(pdevc)) {
 	gx_color_index pixel = COLOR_PIXEL(edev, gx_dc_pure_color(pdevc));
 
-	color_set_pure(ppdc, pixel);
+	set_nonclient_dev_color(ppdc, pixel);
 	reduced = REDUCE_PURE(edev, pixel);
     } else if (gx_dc_is_binary_halftone(pdevc)) {
 	gx_color_index pixel0 =
@@ -169,7 +164,7 @@ reduce_drawing_color(gx_device_color *ppdc, gx_device_plane_extract *edev,
 	    TRANS_COLOR_PIXEL(edev, gx_dc_binary_color1(pdevc));
 
 	if (pixel0 == pixel1) {
-	    color_set_pure(ppdc, pixel0);
+	    set_nonclient_dev_color(ppdc, pixel0);
 	    reduced = REDUCE_PURE(edev, pixel0);
 	} else {
 	    *ppdc = *pdevc;
@@ -190,13 +185,13 @@ reduce_drawing_color(gx_device_color *ppdc, gx_device_plane_extract *edev,
 	    }
 	ppdc->colors.colored.plane_mask &= 1 << plane;
 	if (ppdc->colors.colored.c_level[plane] == 0) {
-	    gx_reduce_colored_halftone(ppdc, (gx_device *)edev, true);
+	    gx_devn_reduce_colored_halftone(ppdc, (gx_device *)edev);
 	    ppdc->colors.pure = COLOR_PIXEL(edev, ppdc->colors.pure);
 	    reduced = REDUCE_PURE(edev, gx_dc_pure_color(ppdc));
 	} else if (ppdc->colors.colored.alpha != gx_max_color_value)
 	    return REDUCE_FAILED; /* can't reduce */
 	else {
-	    gx_reduce_colored_halftone(ppdc, (gx_device *)edev, true);
+	    gx_devn_reduce_colored_halftone(ppdc, (gx_device *)edev);
 	    ppdc->colors.binary.color[0] =
 		COLOR_PIXEL(edev, ppdc->colors.binary.color[0]);
 	    ppdc->colors.binary.color[1] =
@@ -397,6 +392,7 @@ plane_device_init(gx_device_plane_extract *edev, gx_device *target,
     gx_device_init((gx_device *)edev,
 		   (const gx_device *)&gs_plane_extract_device,
 		   edev->memory, true);
+    check_device_separable((gx_device *)edev);
     gx_device_forward_fill_in_procs((gx_device_forward *)edev);
     gx_device_set_target((gx_device_forward *)edev, target);
     gx_device_copy_params((gx_device *)edev, target);
@@ -733,9 +729,9 @@ plane_strip_copy_rop(gx_device *dev,
     long sbuf[COPY_ROP_SOURCE_BUF_SIZE / sizeof(long)];
     long tbuf[COPY_ROP_TEXTURE_BUF_SIZE / sizeof(long)];
     const byte *plane_source;
-    uint plane_raster;
+    uint plane_raster = 0xbaadf00d; /* Initialize against indeterminizm. */
     gx_strip_bitmap plane_texture;
-    const gx_strip_bitmap *plane_textures;
+    const gx_strip_bitmap *plane_textures = NULL;
     int code;
 
     /* We should do better than this on transparency.... */
@@ -893,8 +889,15 @@ plane_cmap_rgb_alpha(frac r, frac g, frac b, frac alpha, gx_device_color * pdc,
 				(gx_device *)edev, select);
     reduce_drawing_color(pdc, edev, &dcolor, &lop);
 }
+private bool
+plane_cmap_is_halftoned(const gs_imager_state *pis_image, gx_device *dev)
+{
+    return false;
+}
+
 private const gx_color_map_procs plane_color_map_procs = {
-    plane_cmap_gray, plane_cmap_rgb, plane_cmap_cmyk, plane_cmap_rgb_alpha
+    plane_cmap_gray, plane_cmap_rgb, plane_cmap_cmyk, plane_cmap_rgb_alpha,
+    NULL, NULL, plane_cmap_is_halftoned
 };
 private const gx_color_map_procs *
 plane_get_cmap_procs(const gs_imager_state *pis, const gx_device *dev)
@@ -961,7 +964,7 @@ plane_begin_typed_image(gx_device * dev,
 	 * The drawing color won't be used, but if RasterOp is involved,
 	 * it may still be accessed in some anomalous cases.
 	 */
-	color_set_pure(&dcolor, (gx_color_index)0);
+	set_nonclient_dev_color(&dcolor, (gx_color_index)0);
     }
     info = gs_alloc_struct(memory, plane_image_enum_t, &st_plane_image_enum,
 			   "plane_image_begin_typed(info)");
@@ -979,7 +982,7 @@ plane_begin_typed_image(gx_device * dev,
     *((gx_image_enum_common_t *)info) = *info->info;
     info->procs = &plane_image_enum_procs;
     info->dev = (gx_device *)edev;
-    info->id = gs_next_ids(1);
+    info->id = gs_next_ids(memory, 1);
     info->memory = memory;
     info->pis = pis;
     info->pis_image = pis_image;
