@@ -1,22 +1,17 @@
-/* Copyright (C) 1994, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevpsim.c,v 1.6.2.1.2.1 2003/01/17 00:49:01 giles Exp $ */
+/* $Id: gdevpsim.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* PostScript image output device */
 #include "gdevprn.h"
 #include "gdevpsu.h"
@@ -64,8 +59,9 @@ ps_image_write_headers(FILE *f, gx_device_printer *pdev,
 	byte buf[100];		/* arbitrary */
 	stream s;
 
+	s_init(&s, pdev->memory);
 	swrite_file(&s, f, buf, sizeof(buf));
-	psw_write_page_header(&s, (gx_device *)pdev, pdpc, true, pdev->PageCount + 1);
+	psw_write_page_header(&s, (gx_device *)pdev, pdpc, true, pdev->PageCount + 1, 10);
 	sflush(&s);
     }
 }
@@ -136,11 +132,11 @@ private const char *const psmono_setup[] = {
     "  2 index read pop dup .ImageProcs exch get exec",
     "} bind def",
 		/* Read and print an entire compressed image. */
-    "/.ImageRead {"	/* <xres> <yres> <width> <height> <bpc> .ImageRead - */
+    "/.ImageRead {"	/* <width> <height> <bpc> .ImageRead - */
     "  gsave [",
-	/* Stack: xres yres width height bpc -mark- */
-    "    6 -2 roll exch 72 div 0 0 4 -1 roll -72 div 0 7 index",
-	/* Stack: width height bpc -mark- xres/72 0 0 -yres/72 0 height */
+      /* Stack: width height bpc -mark- */
+    "    1 0 0 -1 0 7 index",
+      /* Stack: width height bpc -mark- 1 0 0 -1 0 height */
     "  ] { .ImageItem }",
 	/* Stack: width height bpc <matrix> <proc> */
     "  4 index 3 index mul 7 add 8 idiv string currentfile 0 ()",
@@ -162,7 +158,7 @@ static const gx_device_pswrite_common_t psmono_values =
 #define max_repeat_run 255
 
 /* Send the page to the printer. */
-private void write_data_run(P4(const byte *, int, FILE *, byte));
+private void write_data_run(const byte *, int, FILE *, byte);
 private int
 psmono_print_page(gx_device_printer * pdev, FILE * prn_stream)
 {
@@ -182,8 +178,7 @@ psmono_print_page(gx_device_printer * pdev, FILE * prn_stream)
 
     /* Write the .ImageRead command. */
     fprintf(prn_stream,
-	    "%g %g %d %d %d .ImageRead\n",
-	    pdev->HWResolution[0], pdev->HWResolution[1],
+	    "%d %d %d .ImageRead\n",
 	    pdev->width, pdev->height, pdev->color_info.depth);
 
     /* Compress each scan line in turn. */
@@ -231,7 +226,9 @@ psmono_print_page(gx_device_printer * pdev, FILE * prn_stream)
 		    putc(repeat_run_code + count_left,
 			 prn_stream);
 	    }
-	}
+            if (ferror(prn_stream))
+	        return_error(gs_error_ioerror);
+        }
 	/* Write the remaining data, if any. */
 	write_data_run(p, left, prn_stream, invert);
     }
@@ -240,6 +237,8 @@ psmono_print_page(gx_device_printer * pdev, FILE * prn_stream)
     fputs("\n", prn_stream);
     psw_write_page_trailer(prn_stream, 1, true);
     gs_free_object(pdev->memory, line, "psmono_print_page");
+    if (ferror(prn_stream))
+	return_error(gs_error_ioerror);
     return 0;
 }
 
@@ -247,8 +246,11 @@ psmono_print_page(gx_device_printer * pdev, FILE * prn_stream)
 private int
 psmono_close(gx_device *dev)
 {
-    psw_end_file(((gx_device_printer *)dev)->file, dev, &psmono_values, NULL, 
-                 dev->PageCount);
+    int code = psw_end_file(((gx_device_printer *)dev)->file, dev, 
+            &psmono_values, NULL, dev->PageCount);
+    
+    if (code < 0)
+        return code;
     return gdev_prn_close(dev);
 }
 
@@ -356,11 +358,13 @@ psrgb_print_page(gx_device_printer * pdev, FILE * prn_stream)
 	return_error(gs_error_VMerror);
     ps_image_write_headers(prn_stream, pdev, psrgb_setup, &pswrite_common);
     fprintf(prn_stream, "%d %d rgbimage\n", width, pdev->height);
+    s_init(&fs, mem);
     swrite_file(&fs, prn_stream, fsbuf, sizeof(fsbuf));
     fs.memory = 0;
 
     if (s_A85E_template.set_defaults)
 	(*s_A85E_template.set_defaults) ((stream_state *) & a85state);
+    s_init(&a85s, mem);
     s_std_init(&a85s, a85sbuf, sizeof(a85sbuf), &s_filter_write_procs,
 	       s_mode_write);
     a85s.memory = 0;
@@ -372,6 +376,7 @@ psrgb_print_page(gx_device_printer * pdev, FILE * prn_stream)
     a85s.strm = &fs;
 
     (*s_RLE_template.set_defaults) ((stream_state *) & rlstate);
+    s_init(&rls, mem);
     s_std_init(&rls, rlsbuf, sizeof(rlsbuf), &s_filter_write_procs,
 	       s_mode_write);
     rls.memory = 0;
@@ -392,6 +397,8 @@ psrgb_print_page(gx_device_printer * pdev, FILE * prn_stream)
 
 	    for (i = 0, p = data + c; i < width; ++i, p += 3)
 		sputc(&rls, *p);
+            if (rls.end_status == ERRC)
+              return_error(gs_error_ioerror);
 	}
     }
     sclose(&rls);
@@ -400,6 +407,8 @@ psrgb_print_page(gx_device_printer * pdev, FILE * prn_stream)
     fputs("\n", prn_stream);
     psw_write_page_trailer(prn_stream, 1, true);
     gs_free_object(mem, lbuf, "psrgb_print_page(lbuf)");
+    if (ferror(prn_stream))
+        return_error(gs_error_ioerror);
     return 0;
 }
 
@@ -407,7 +416,10 @@ psrgb_print_page(gx_device_printer * pdev, FILE * prn_stream)
 private int
 psrgb_close(gx_device *dev)
 {
-    psw_end_file(((gx_device_printer *)dev)->file, dev, &psrgb_values, NULL, 
-                 dev->PageCount);
+    int code = psw_end_file(((gx_device_printer *)dev)->file, dev,
+            &psrgb_values, NULL, dev->PageCount);
+    
+    if (code < 0)
+        return code;
     return gdev_prn_close(dev);
 }
