@@ -1,22 +1,17 @@
-/* Copyright (C) 1997, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gscolor3.c,v 1.4.6.1.2.1 2003/01/17 00:49:02 giles Exp $ */
+/* $Id: gscolor3.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* "Operators" for LanguageLevel 3 color facilities */
 #include "gx.h"
 #include "gserrors.h"
@@ -25,6 +20,7 @@
 #include "gsptype2.h"
 #include "gxcolor2.h"		/* for gxpcolor.h */
 #include "gxcspace.h"		/* for gs_cspace_init */
+#include "gxdcolor.h"		/* for gxpcolor.h */
 #include "gxpcolor.h"		/* for gs_color_space_type_Pattern */
 #include "gzstate.h"
 #include "gzpath.h"
@@ -75,7 +71,10 @@ gs_shfill(gs_state * pgs, const gs_shading_t * psh)
 			   pgs->memory);
     if (code < 0)
 	return code;
-    gs_cspace_init(&cs, &gs_color_space_type_Pattern, NULL);
+    code = gs_pattern2_set_shfill(&cc);
+    if (code < 0)
+	return code;
+    gs_cspace_init(&cs, &gs_color_space_type_Pattern, pgs->memory, false);
     cs.params.pattern.has_base_space = false;
     code = cs.type->remap_color(&cc, &cs, &devc, (gs_imager_state *)pgs,
 				pgs->device, gs_color_select_texture);
@@ -84,7 +83,7 @@ gs_shfill(gs_state * pgs, const gs_shading_t * psh)
 	code = gx_cpath_to_path(pgs->clip_path, &cpath);
 	if (code >= 0)
 	    code = gx_fill_path(&cpath, &devc, pgs, gx_rule_winding_number,
-				fixed_0, fixed_0);
+				pgs->fill_adjust.x, pgs->fill_adjust.y);
 	gx_path_free(&cpath, "gs_shfill");
     }
     gs_pattern_reference(&cc, -1);
