@@ -1,25 +1,16 @@
-/*
-  Copyright (C) 2001 artofcode LLC.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
-
-
-  Author: Raph Levien <raph@artofcode.com>
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
-
-/* $Id: gsdfilt.h,v 1.2.2.2.2.1 2003/01/17 00:49:02 giles Exp $ */
+/* $Id: gsdfilt.h 6651 2006-03-13 16:18:19Z stefan $ */
 
 #ifndef gsdfilt_INCLUDED
 #  define gsdfilt_INCLUDED
@@ -34,30 +25,27 @@
    chain.
 */
 
-#define DFILTER_TEST
-
 #ifndef gs_device_filter_stack_DEFINED
 #  define gs_device_filter_stack_DEFINED
 typedef struct gs_device_filter_stack_s gs_device_filter_stack_t;
 #endif
 
-/* This is the base structure from which device filters are derived. */
+#ifndef gs_device_filter_DEFINED
+#  define gs_device_filter_DEFINED
 typedef struct gs_device_filter_s gs_device_filter_t;
+#endif
 
 struct gs_device_filter_s {
-    int (*push)(gs_device_filter_t *self, gs_memory_t *mem,
+    int (*push)(gs_device_filter_t *self, gs_memory_t *mem, gs_state *pgs,
 		gx_device **pdev, gx_device *target);
-    int (*pop)(gs_device_filter_t *self, gs_memory_t *mem, gs_state *pgs,
-	       gx_device *dev);
+    int (*prepop)(gs_device_filter_t *self, gs_memory_t *mem, gs_state *pgs,
+		  gx_device *dev);
+    int (*postpop)(gs_device_filter_t *self, gs_memory_t *mem, gs_state *pgs,
+		   gx_device *dev);
 };
 
 extern_st(st_gs_device_filter);
 
-#ifdef DFILTER_TEST
-int gs_test_device_filter(gs_device_filter_t **pdf, gs_memory_t *mem);
-#endif
-
-
 /**
  * gs_push_device_filter: Push a device filter.
  * @mem: Memory for creating device filter.
@@ -93,4 +81,5 @@ int gs_pop_device_filter(gs_memory_t *mem, gs_state *pgs);
  **/
 int gs_clear_device_filters(gs_memory_t *mem, gs_state *pgs);
 
+
 #endif /* gsdfilt_INCLUDED */
