@@ -1,22 +1,17 @@
-/* Copyright (C) 1996, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gsiparam.h,v 1.4.6.1.2.1 2003/01/17 00:49:02 giles Exp $ */
+/* $Id: gsiparam.h 6651 2006-03-13 16:18:19Z stefan $ */
 /* Image parameter definition */
 
 #ifndef gsiparam_INCLUDED
@@ -242,22 +237,23 @@ void
   /*
    * Sets ImageMatrix to the identity matrix.
    */
-     gs_image_common_t_init(P1(gs_image_common_t * pic)),	/*
-								 * Also sets Width = Height = 0, BitsPerComponent = 1,
-								 * format = chunky, Interpolate = false.
-								 * If num_components = N > 0, sets the first N elements of Decode to (0, 1);
-								 * if num_components = N < 0, sets the first -N elements of Decode to (1, 0);
-								 * if num_components = 0, doesn't set Decode.
-								 */
-     gs_data_image_t_init(P2(gs_data_image_t * pim, int num_components)),
+     gs_image_common_t_init(gs_image_common_t * pic),
+  /*
+   * Also sets Width = Height = 0, BitsPerComponent = 1,
+   * format = chunky, Interpolate = false.
+   * If num_components = N > 0, sets the first N elements of Decode to (0, 1);
+   * if num_components = N < 0, sets the first -N elements of Decode to (1, 0);
+   * if num_components = 0, doesn't set Decode.
+   */
+     gs_data_image_t_init(gs_data_image_t * pim, int num_components),
   /*
    * Also sets CombineWithColor = false, ColorSpace = color_space, Alpha =
    * none.  num_components is obtained from ColorSpace; if ColorSpace =
    * NULL or ColorSpace is a Pattern space, num_components is taken as 0
    * (Decode is not initialized).
    */
-    gs_pixel_image_t_init(P2(gs_pixel_image_t * pim,
-			     const gs_color_space * color_space));
+    gs_pixel_image_t_init(gs_pixel_image_t * pim,
+			  const gs_color_space * color_space);
 
 /*
  * Initialize an ImageType 1 image (or imagemask).  Also sets ImageMask,
@@ -271,22 +267,15 @@ void
  * Note that for init and init_adjust, adjust is only relevant if
  * pim->ImageMask is true.
  */
-void gs_image_t_init_adjust(P3(gs_image_t * pim, const gs_color_space * pcs,
-			       bool adjust));
+void gs_image_t_init_adjust(gs_image_t * pim, const gs_color_space * pcs,
+			    bool adjust);
 #define gs_image_t_init(pim, pcs)\
   gs_image_t_init_adjust(pim, pcs, true)
-void gs_image_t_init_mask_adjust(P3(gs_image_t * pim, bool write_1s,
-				    bool adjust));
+void gs_image_t_init_mask_adjust(gs_image_t * pim, bool write_1s,
+				 bool adjust);
 #define gs_image_t_init_mask(pim, write_1s)\
   gs_image_t_init_mask_adjust(pim, write_1s, true)
 
-/* init_gray and init_color require a (const) imager state. */
-#define gs_image_t_init_gray(pim, pis)\
-  gs_image_t_init(pim, gs_cspace_DeviceGray(pis))
-#define gs_image_t_init_rgb(pim, pis)\
-  gs_image_t_init(pim, gs_cspace_DeviceRGB(pis))
-#define gs_image_t_init_cmyk(pim, pis)\
-  gs_image_t_init(pim, gs_cspace_DeviceCMYK(pis))
 
 /****** REMAINDER OF FILE UNDER CONSTRUCTION. PROCEED AT YOUR OWN RISK. ******/
 
@@ -299,11 +288,11 @@ void gs_image_t_init_mask_adjust(P3(gs_image_t * pim, bool write_1s,
    procedure:
  */
 
-int gx_map_image_color(P5(gx_device * dev,
-			  const gs_image_t * pim,
-			  const gx_color_rendering_info * pcri,
-			  const uint components[GS_IMAGE_MAX_COMPONENTS],
-			  gx_drawing_color * pdcolor));
+int gx_map_image_color(gx_device * dev,
+		       const gs_image_t * pim,
+		       const gx_color_rendering_info * pcri,
+		       const uint components[GS_IMAGE_MAX_COMPONENTS],
+		       gx_drawing_color * pdcolor);
 
 /*
   Map a source color to a drawing color.  The components are simply the
