@@ -1,22 +1,17 @@
-/* Copyright (C) 1997, 1998, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gstrap.h,v 1.3.6.1.2.1 2003/01/17 00:49:03 giles Exp $ */
+/* $Id: gstrap.h 6651 2006-03-13 16:18:19Z stefan $ */
 /* Definitions for trapping parameters and zones */
 
 #ifndef gstrap_INCLUDED
@@ -71,6 +66,6 @@ typedef struct gs_trap_zone_s {
 
 /* ---------------- Procedures ---------------- */
 
-int gs_settrapparams(P2(gs_trap_params_t * params, gs_param_list * list));
+int gs_settrapparams(gs_trap_params_t * params, gs_param_list * list);
 
 #endif /* gstrap_INCLUDED */
