@@ -1,22 +1,17 @@
-/* Copyright (C) 1995, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxalloc.h,v 1.6.2.1.2.1 2003/01/17 00:49:03 giles Exp $ */
+/* $Id: gxalloc.h 6707 2006-04-16 19:01:41Z leonardo $ */
 /* Structure definitions for standard allocator */
 /* Requires gsmemory.h, gsstruct.h */
 
@@ -31,6 +26,8 @@ typedef struct gs_ref_memory_s gs_ref_memory_t;
 #include "gsalloc.h"
 #include "gxobj.h"
 
+#define NO_INVISIBLE_LEVELS 1 /* old code = 0, new code = 1 */
+
 /* ================ Chunks ================ */
 
 /*
@@ -201,6 +198,8 @@ extern_st(st_chunk);
  *      DO_ALL
  *              << code for all objects -- size is set >>
  *      END_OBJECTS_SCAN
+ *
+ * NB on error END_OBJECTS_SCAN calls gs_abort in debug systems.
  */
 #define SCAN_CHUNK_OBJECTS(cp)\
 	{	obj_header_t *pre = (obj_header_t *)((cp)->cbase);\
@@ -214,7 +213,7 @@ extern_st(st_chunk);
 #define DO_ALL\
 			size = pre_obj_contents_size(pre);\
 			{
-#define END_OBJECTS_SCAN_INCOMPLETE\
+#define END_OBJECTS_SCAN_NO_ABORT\
 			}\
 		}\
 	}
@@ -225,19 +224,19 @@ extern_st(st_chunk);
 		if ( pre != end )\
 		{	lprintf2("Chunk parsing error, 0x%lx != 0x%lx\n",\
 				 (ulong)pre, (ulong)end);\
-			gs_abort();\
+		    /*gs_abort((const gs_memory_t *)NULL);*/	\
 		}\
 	}
 #else
-#  define END_OBJECTS_SCAN END_OBJECTS_SCAN_INCOMPLETE
+#  define END_OBJECTS_SCAN END_OBJECTS_SCAN_NO_ABORT
 #endif
 
 /* Initialize a chunk. */
 /* This is exported for save/restore. */
-void alloc_init_chunk(P5(chunk_t *, byte *, byte *, bool, chunk_t *));
+void alloc_init_chunk(chunk_t *, byte *, byte *, bool, chunk_t *);
 
 /* Initialize the string freelists in a chunk. */
-void alloc_init_free_strings(P1(chunk_t *));
+void alloc_init_free_strings(chunk_t *);
 
 /* Find the chunk for a pointer. */
 /* Note that ptr_is_within_chunk returns true even if the pointer */
@@ -253,7 +252,7 @@ typedef struct chunk_locator_s {
     const gs_ref_memory_t *memory;	/* for head & tail of chain */
     chunk_t *cp;		/* one-element cache */
 } chunk_locator_t;
-bool chunk_locate_ptr(P2(const void *, chunk_locator_t *));
+bool chunk_locate_ptr(const void *, chunk_locator_t *);
 
 #define chunk_locate(ptr, clp)\
   (((clp)->cp != 0 && ptr_is_in_chunk(ptr, (clp)->cp)) ||\
@@ -261,18 +260,18 @@ bool chunk_locate_ptr(P2(const void *, chunk_locator_t *));
 
 /* Close up the current chunk. */
 /* This is exported for save/restore and for the GC. */
-void alloc_close_chunk(P1(gs_ref_memory_t * mem));
+void alloc_close_chunk(gs_ref_memory_t * mem);
 
 /* Reopen the current chunk after a GC. */
-void alloc_open_chunk(P1(gs_ref_memory_t * mem));
+void alloc_open_chunk(gs_ref_memory_t * mem);
 
 /* Insert or remove a chunk in the address-ordered chain. */
 /* These are exported for the GC. */
-void alloc_link_chunk(P2(chunk_t *, gs_ref_memory_t *));
-void alloc_unlink_chunk(P2(chunk_t *, gs_ref_memory_t *));
+void alloc_link_chunk(chunk_t *, gs_ref_memory_t *);
+void alloc_unlink_chunk(chunk_t *, gs_ref_memory_t *);
 
 /* Free a chunk.  This is exported for save/restore and for the GC. */
-void alloc_free_chunk(P2(chunk_t *, gs_ref_memory_t *));
+void alloc_free_chunk(chunk_t *, gs_ref_memory_t *);
 
 /* Print a chunk debugging message. */
 /* Unfortunately, the ANSI C preprocessor doesn't allow us to */
@@ -333,12 +332,14 @@ typedef struct ref_s ref;
 struct gs_ref_memory_s {
     /* The following are set at initialization time. */
     gs_memory_common;
-    gs_raw_memory_t *parent;	/* for allocating chunks */
     uint chunk_size;
     uint large_size;		/* min size to give large object */
 				/* its own chunk: must be */
 				/* 1 mod obj_align_mod */
     uint space;			/* a_local, a_global, a_system */
+#   if IGC_PTR_STABILITY_CHECK
+    unsigned space_id:3; /* r_space_bits + 1 bit for "instability". */
+#   endif
     /* Callers can change the following dynamically */
     /* (through a procedural interface). */
     gs_memory_gc_status_t gc_status;
@@ -381,6 +382,9 @@ struct gs_ref_memory_s {
     /* Sharing / saved state information */
     int num_contexts;		/* # of contexts sharing this VM */
     struct alloc_change_s *changes;
+#if NO_INVISIBLE_LEVELS
+    struct alloc_change_s *scan_limit;
+#endif
     struct alloc_save_s *saved;
     long total_scanned;
     struct alloc_save_s *reloc_saved;	/* for GC */
@@ -397,7 +401,7 @@ extern_st(st_ref_memory);
 #define public_st_ref_memory()	/* in gsalloc.c */\
   gs_public_st_composite(st_ref_memory, gs_ref_memory_t,\
     "gs_ref_memory", ref_memory_enum_ptrs, ref_memory_reloc_ptrs)
-#define st_ref_memory_max_ptrs 4  /* streams, names_array, changes, saved */
+#define st_ref_memory_max_ptrs 5  /* streams, names_array, changes, scan_limit, saved */
 
 /* Define the procedures for the standard allocator. */
 /* We export this for subclasses. */
@@ -453,20 +457,20 @@ extern const dump_control_t dump_control_all;
 /* Print one object with the given options. */
 /* Relevant options: type_addresses, no_types, pointers, pointed_strings, */
 /* contents. */
-void debug_print_object(P2(const void *obj, const dump_control_t * control));
+void debug_print_object(const gs_memory_t *mem, const void *obj, const dump_control_t * control);
 
 /* Print the contents of a chunk with the given options. */
 /* Relevant options: all. */
-void debug_dump_chunk(P2(const chunk_t * cp, const dump_control_t * control));
-void debug_print_chunk(P1(const chunk_t * cp));	/* default options */
+void debug_dump_chunk(const gs_memory_t *mem, const chunk_t * cp, const dump_control_t * control);
+void debug_print_chunk(const gs_memory_t *mem, const chunk_t * cp);	/* default options */
 
 /* Print the contents of all chunks managed by an allocator. */
 /* Relevant options: all. */
-void debug_dump_memory(P2(const gs_ref_memory_t * mem,
-			  const dump_control_t * control));
+void debug_dump_memory(const gs_ref_memory_t *mem,
+		       const dump_control_t *control);
 
 /* Find all the objects that contain a given pointer. */
-void debug_find_pointers(P2(const gs_ref_memory_t *mem, const void *target));
+void debug_find_pointers(const gs_ref_memory_t *mem, const void *target);
 
 #endif /* DEBUG */
 
