@@ -1,20 +1,17 @@
-/* Copyright (C) 1995, 1996, 1997, 1998 Aladdin Enterprises.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This software is provided AS-IS with no warranty, either express or
-  implied.
-  
-  This software is distributed under license and may not be copied,
-  modified or distributed except as expressly authorized under the terms
-  of the license contained in the file LICENSE in this distribution.
-  
-  For more information about licensing, please refer to
-  http://www.ghostscript.com/licensing/. For information on
-  commercial licensing, go to http://www.artifex.com/licensing/ or
-  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
-  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
+
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxclmem.c,v 1.2.6.1 2002/02/22 19:45:58 ray Exp $ */
+/* $Id: gxclmem.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* RAM-based command list implementation */
 #include "memory_.h"
 #include "gx.h"
@@ -153,8 +150,8 @@ private const long COMPRESSION_THRESHOLD = 300000;
 private_st_MEMFILE();
 
 	/* forward references */
-private void memfile_free_mem(P1(MEMFILE * f));
-private int memfile_init_empty(P1(MEMFILE * f));
+private void memfile_free_mem(MEMFILE * f);
+private int memfile_init_empty(MEMFILE * f);
 
 /************************************************/
 /*   #define DEBUG      /- force statistics -/  */
