@@ -1,22 +1,17 @@
-/* Copyright (C) 1995, 1996, 1997, 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxpdash.c,v 1.2.6.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: gxpdash.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Dash expansion for paths */
 #include "math_.h"
 #include "gx.h"
@@ -29,9 +24,9 @@
 
 /* Expand a dashed path into explicit segments. */
 /* The path contains no curves. */
-private int subpath_expand_dashes(P4(const subpath *, gx_path *,
-				     const gs_imager_state *,
-				     const gx_dash_params *));
+private int subpath_expand_dashes(const subpath *, gx_path *,
+				  const gs_imager_state *,
+				  const gx_dash_params *);
 int
 gx_path_add_dash_expansion(const gx_path * ppath_old, gx_path * ppath,
 			   const gs_imager_state * pis)
@@ -86,10 +81,17 @@ subpath_expand_dashes(const subpath * psub, gx_path * ppath,
 	double scale = 1;
 	double left;
 
-	if (!(udx | udy))	/* degenerate */
+	if (!(udx | udy)) {	/* degenerate */
+	    if (gs_currentlinecap((const gs_state *)pis) != gs_cap_round) {
+		/* From PLRM, stroke operator :
+		   If a subpath is degenerate (consists of a single-point closed path 
+		   or of two or more points at the same coordinates), 
+		   stroke paints it only if round line caps have been specified */
+		continue;
+	    }
 	    dx = 0, dy = 0, length = 0;
-	else {
-	    gs_point d;
+	} else {
+  	    gs_point d;
 
 	    dx = udx, dy = udy;	/* scaled as fixed */
 	    gs_imager_idtransform(pis, dx, dy, &d);
