@@ -1,22 +1,17 @@
-/* Copyright (C) 1992, 1993, 1994, 1996 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gxxfont.h,v 1.2.6.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: gxxfont.h 6651 2006-03-13 16:18:19Z stefan $ */
 /* External font interface for Ghostscript library */
 
 #ifndef gxxfont_INCLUDED
@@ -94,29 +89,34 @@ struct gx_xfont_procs_s {
     /* does not take an xfont * as its first argument. */
 
 #define xfont_proc_lookup_font(proc)\
-  gx_xfont *proc(P7(gx_device *dev, const byte *fname, uint len,\
+  gx_xfont *proc(gx_device *dev, const byte *fname, uint len,\
     int encoding_index, const gs_uid *puid, const gs_matrix *pmat,\
-    gs_memory_t *mem))
+    gs_memory_t *mem)
     xfont_proc_lookup_font((*lookup_font));
 
     /*
      * Convert a character name to an xglyph code.  encoding_index is
      * actually a gs_encoding_index_t.  Either chr or glyph may be absent
-     * (gs_no_char/glyph), but not both.
+     * (gs_no_char/glyph), but not both.  glyph_name is the glyph's
+     * (string) name if the glyph is not GS_NO_GLYPH and is not a CID.
+     */
+    /*
+     * This procedure was deprecated as of release 3.43, but still
+     * supported.  In release 7.21, the argument list was changed, and the
+     * procedure is no longer deprecated.
      */
-    /* OBSOLETE as of release 3.43, but still supported. */
 
 #define xfont_proc_char_xglyph(proc)\
-  gx_xglyph proc(P5(gx_xfont *xf, gs_char chr, int encoding_index,\
-    gs_glyph glyph, gs_proc_glyph_name((*glyph_name))))
+  gx_xglyph proc(gx_xfont *xf, gs_char chr, int encoding_index,\
+    gs_glyph glyph, const gs_const_string *glyph_name)
     xfont_proc_char_xglyph((*char_xglyph));
 
     /* Get the metrics for a character. */
     /* Note: pwidth changed in release 2.9.7. */
 
 #define xfont_proc_char_metrics(proc)\
-  int proc(P5(gx_xfont *xf, gx_xglyph xg, int wmode,\
-    gs_point *pwidth, gs_int_rect *pbbox))
+  int proc(gx_xfont *xf, gx_xglyph xg, int wmode,\
+    gs_point *pwidth, gs_int_rect *pbbox)
     xfont_proc_char_metrics((*char_metrics));
 
     /* Render a character. */
@@ -124,8 +124,8 @@ struct gx_xfont_procs_s {
     /* The target may be any Ghostscript device. */
 
 #define xfont_proc_render_char(proc)\
-  int proc(P7(gx_xfont *xf, gx_xglyph xg, gx_device *target,\
-    int x, int y, gx_color_index color, int required))
+  int proc(gx_xfont *xf, gx_xglyph xg, gx_device *target,\
+    int x, int y, gx_color_index color, int required)
     xfont_proc_render_char((*render_char));
 
     /* Release any external resources associated with an xfont. */
@@ -133,18 +133,11 @@ struct gx_xfont_procs_s {
     /* allocated by lookup_font (including the xfont itself). */
 
 #define xfont_proc_release(proc)\
-  int proc(P2(gx_xfont *xf, gs_memory_t *mem))
+  int proc(gx_xfont *xf, gs_memory_t *mem)
     xfont_proc_release((*release));
 
-    /* Convert a character name to an xglyph code. */
-    /* This is the same as char_xglyph, except that */
-    /* it takes a vector of callback procedures. */
-    /* (New in release 3.43.) */
-
-#define xfont_proc_char_xglyph2(proc)\
-  gx_xglyph proc(P5(gx_xfont *xf, gs_char chr, int encoding_index,\
-    gs_glyph glyph, const gx_xfont_callbacks *callbacks))
-    xfont_proc_char_xglyph2((*char_xglyph2));
+    /* (There was a char_xglyph2 procedure here, added in release 3.43, */
+    /* removed in 7.21.) */
 
 };
 
