@@ -1,22 +1,17 @@
-/* Copyright (C) 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: idstack.c,v 1.2.6.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: idstack.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Implementation of dictionary stacks */
 #include "ghost.h"
 #include "idict.h"
@@ -44,7 +39,7 @@ struct stats_dstack_s {
 
 #ifdef DEBUG
 /* Wrapper for dstack_find_name_by_index */
-ref *real_dstack_find_name_by_index(P2(dict_stack_t * pds, uint nidx));
+ref *real_dstack_find_name_by_index(dict_stack_t * pds, uint nidx);
 ref *
 dstack_find_name_by_index(dict_stack_t * pds, uint nidx)
 {
@@ -112,14 +107,14 @@ dstack_find_name_by_index(dict_stack_t * pds, uint nidx)
     do {
 	dict *pdict = pdref->value.pdict;
 	uint size = npairs(pdict);
-
+	const gs_memory_t *mem = dict_mem(pdict);
 #ifdef DEBUG
 	if (gs_debug_c('D')) {
 	    ref dnref;
 
-	    name_index_ref(nidx, &dnref);
+	    name_index_ref(mem, nidx, &dnref);
 	    dlputs("[D]lookup ");
-	    debug_print_name(&dnref);
+	    debug_print_name(mem, &dnref);
 	    dprintf3(" in 0x%lx(%u/%u)\n",
 		     (ulong) pdict, dict_length(pdref),
 		     dict_maxlength(pdref));
@@ -144,7 +139,7 @@ dstack_find_name_by_index(dict_stack_t * pds, uint nidx)
 	    for (kp = kbot + dict_hash_mod(hash, size) + 2;;) {
 		--kp;
 		if (r_has_type(kp, t_name)) {
-		    if (name_index(kp) == nidx) {
+		    if (name_index(mem, kp) == nidx) {
 			INCR_DEPTH(pdref);
 			return pdict->values.value.refs + (kp - kbot);
 		    }
@@ -172,9 +167,12 @@ dstack_find_name_by_index(dict_stack_t * pds, uint nidx)
 	ref key;
 	uint i = pds->stack.p + 1 - pds->stack.bot;
 	uint size = ref_stack_count(&pds->stack);
-	ref *pvalue;
+	ref *pvalue;	
+	
+	dict *pdict = pds->stack.p->value.pdict;
+	const gs_memory_t *mem = dict_mem(pdict);
 
-	name_index_ref(nidx, &key);
+	name_index_ref(mem, nidx, &key);
 	for (; i < size; i++) {
 	    if (dict_find(ref_stack_index(&pds->stack, i),
 			  &key, &pvalue) > 0
@@ -235,7 +233,7 @@ dstack_gc_cleanup(dict_stack_t * pds)
 	    ref key;
 	    ref *old_pvalue;
 
-	    array_get(&pdict->keys, (long)i, &key);
+	    array_get(dict_mem(pdict), &pdict->keys, (long)i, &key);
 	    if (r_has_type(&key, t_name) &&
 		pv_valid(old_pvalue = key.value.pname->pvalue)
 		) {		/*
