@@ -1,22 +1,17 @@
-/* Copyright (C) 1994, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: ifilter.h,v 1.3.6.1.2.1 2003/01/17 00:49:04 giles Exp $ */
+/* $Id: ifilter.h 6651 2006-03-13 16:18:19Z stefan $ */
 /* Interpreter filter support */
 /* Requires oper.h, stream.h, strimpl.h */
 
@@ -31,41 +26,41 @@
  * Note that a filter will be allocated in global VM iff the source/target
  * and all relevant parameters (if any) are in global VM.
  */
-int filter_read(P5(
+int filter_read(
 	/* Operator arguments that were passed to zfxxx operator */
-		   i_ctx_t *i_ctx_p,
+		i_ctx_t *i_ctx_p,
 	/* # of parameters to pop off o-stack, */
 	/* not counting the source/target and also not counting any */
 	/* top dictionary operand (both of which will always be popped) */
-		   int npop,
+		int npop,
 	/* Template for stream */
-		   const stream_template * template,
+		const stream_template * template,
 	/* Initialized s_xxx_state, 0 if no separate state */
-		   stream_state * st,
+		stream_state * st,
 	/* Max of space attributes of all parameters referenced by */
 	/* the state, 0 if no such parameters */
-		   uint space
-		));
-int filter_write(P5(i_ctx_t *i_ctx_p, int npop,
-		    const stream_template * template,
-		    stream_state * st, uint space));
+		uint space
+		);
+int filter_write(i_ctx_t *i_ctx_p, int npop,
+		 const stream_template * template,
+		 stream_state * st, uint space);
 
 /*
  * Define a simplified interface for streams with no parameters (except
  * an optional dictionary) or state.
  */
-int filter_read_simple(P2(i_ctx_t *i_ctx_p,
-			  const stream_template * template));
-int filter_write_simple(P2(i_ctx_t *i_ctx_p,
-			   const stream_template * template));
+int filter_read_simple(i_ctx_t *i_ctx_p,
+		       const stream_template * template);
+int filter_write_simple(i_ctx_t *i_ctx_p,
+			const stream_template * template);
 
 /* Mark a filter stream as temporary. */
 /* See stream.h for the meaning of is_temp. */
-void filter_mark_temp(P2(const ref * fop, int is_temp));
+void filter_mark_temp(const ref * fop, int is_temp);
 
 /* Mark the source or target of a filter as temporary, and propagate */
 /* close_strm from the temporary stream to the filter. */
-void filter_mark_strm_temp(P2(const ref * fop, int is_temp));
+void filter_mark_strm_temp(const ref * fop, int is_temp);
 
 /* Define a standard report_error procedure for filters, */
 /* that records the error message in $error.errorinfo. */
@@ -90,6 +85,6 @@ typedef struct stream_proc_state_s {
     "procedure stream state", sproc_clear_marks, sproc_enum_ptrs, sproc_reloc_ptrs, 0)
 
 /* Test whether a stream is procedure-based. */
-bool s_is_proc(P1(const stream *s));
+bool s_is_proc(const stream *s);
 
 #endif /* ifilter_INCLUDED */
