@@ -1,22 +1,17 @@
-/* Copyright (C) 1991, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: sfilter2.c,v 1.3.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: sfilter2.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Simple Level 2 filters */
 #include "stdio_.h"		/* includes std.h */
 #include "memory_.h"
@@ -179,39 +174,49 @@ put:	    if (q + 5 > qn) {
     ss->count = LINE_LIMIT - (qn - q);
     /* Check for final partial word. */
     if (last && status == 0 && count < 4) {
-	int nchars = (count == 0 ? 2 : count + 3);
+	char buf[5];
+        int nchars = (count == 0 ? 2 : count + 3);
+	ulong word = 0;
+	ulong divisor = 85L * 85 * 85 * 85;
+        int i, space;
 
-	if (wlimit - q < nchars)
+	switch (count) {
+	    case 3:
+		word += (uint) p[3] << 8;
+	    case 2:
+		word += (ulong) p[2] << 16;
+	    case 1:
+		word += (ulong) p[1] << 24;
+                for(i=0; i <= count; i++) {
+		    ulong v = word / divisor;  /* actually only a byte */
+
+		    buf[i] = (byte) v + '!';
+		    word -= v * divisor;
+		    divisor /= 85;
+		}
+		/*case 0: */
+	}
+        space = count && buf[0] == '%' && 
+          ( (prev == '\n' && ( buf[1] == '%' || buf[1] =='!')) ||
+            (prev == '%'  && qn - q == LINE_LIMIT - 1)
+          );   
+        if (wlimit - q < nchars+space)
 	    status = 1;
-	else if (q + nchars > qn) {
-	    *++q = '\n';
+	else if (q + nchars+space > qn) {
+	    *++q = prev = '\n';
 	    qn = q + LINE_LIMIT;
 	    goto end;
-	}
-	else {
-	    ulong word = 0;
-	    ulong divisor = 85L * 85 * 85 * 85;
-
-	    switch (count) {
-		case 3:
-		    word += (uint) p[3] << 8;
-		case 2:
-		    word += (ulong) p[2] << 16;
-		case 1:
-		    word += (ulong) p[1] << 24;
-		    p += count;
-		    while (count-- >= 0) {
-			ulong v = word / divisor;  /* actually only a byte */
-
-			*++q = (byte) v + '!';
-			word -= v * divisor;
-			divisor /= 85;
-		    }
-		    /*case 0: */
-	    }
-	    *++q = '~';
-	    *++q = '>';
-	}
+	} else {
+            if (count) {
+                if (space)
+  	          *++q = ' ';
+                memcpy(q+1, buf, count+1);
+                q += count+1;
+	        p += count;
+            }
+            *++q = '~';
+            *++q = '>';
+        }
     }
     if_debug3('w', "[w85]final ss->count = %d, %d bytes read, %d written\n",
 	      ss->count, (int)(p - pr->ptr), (int)(q - pw->ptr));
