@@ -1,23 +1,18 @@
-/* Copyright (C) 1996, 1998 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: sstring.h,v 1.3.4.1.2.1 2003/01/17 00:49:05 giles Exp $ */
-/* are referenced, but some compilers always require strimpl.h. */
+/* $Id: sstring.h 6651 2006-03-13 16:18:19Z stefan $ */
+/* String and hexstring streams (filters) */
 
 #ifndef sstring_INCLUDED
 #  define sstring_INCLUDED
@@ -63,9 +58,14 @@ typedef struct stream_PSSD_state_s {
 #define private_st_PSSD_state()	/* in sstring.c */\
   gs_private_st_simple(st_PSSD_state, stream_PSSD_state,\
     "PSStringDecode state")
-/* We define the initialization procedure here, so that the scanner */
+
+/* Initialize the state */
+int s_PSSD_init(stream_state * st);
+
+/* A special initialization procedure for the scanner */
 /* can avoid a procedure call. */
-#define s_PSSD_init_inline(ss)\
+/* Note : it doesn't initialize ss->from_string. */
+#define s_PSSD_partially_init_inline(ss)\
   ((ss)->depth = 0)
 extern const stream_template s_PSSD_template;
 
