@@ -1,23 +1,18 @@
-/* Copyright (C) 1989, 1992, 1993, 1994, 1995, 1998, 1999, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: std.h,v 1.4.2.1.2.1 2003/01/17 00:49:05 giles Exp $ */
-/* Standard definitions for Aladdin Enterprises code */
+/* $Id: std.h 6774 2006-05-17 18:27:07Z giles $ */
+/* Standard definitions for Ghostscript code */
 
 #ifndef std_INCLUDED
 #  define std_INCLUDED
@@ -31,42 +26,35 @@
  * Define lower-case versions of the architecture parameters for backward
  * compatibility.
  */
-#define arch_align_short_mod ARCH_ALIGN_SHORT_MOD
-#define arch_align_int_mod ARCH_ALIGN_INT_MOD
-#define arch_align_long_mod ARCH_ALIGN_LONG_MOD
-#define arch_align_ptr_mod ARCH_ALIGN_PTR_MOD
-#define arch_align_float_mod ARCH_ALIGN_FLOAT_MOD
-#define arch_align_double_mod ARCH_ALIGN_DOUBLE_MOD
 #define arch_log2_sizeof_short ARCH_LOG2_SIZEOF_SHORT
 #define arch_log2_sizeof_int ARCH_LOG2_SIZEOF_INT
 #define arch_log2_sizeof_long ARCH_LOG2_SIZEOF_LONG
 #define arch_sizeof_ptr ARCH_SIZEOF_PTR
 #define arch_sizeof_float ARCH_SIZEOF_FLOAT
 #define arch_sizeof_double ARCH_SIZEOF_DOUBLE
-#define arch_float_mantissa_bits ARCH_FLOAT_MANTISSA_BITS
-#define arch_double_mantissa_bits ARCH_DOUBLE_MANTISSA_BITS
-#define arch_max_uchar ARCH_MAX_UCHAR
-#define arch_max_ushort ARCH_MAX_USHORT
-#define arch_max_uint ARCH_MAX_UINT
-#define arch_max_ulong ARCH_MAX_ULONG
-#define arch_cache1_size ARCH_CACHE1_SIZE
-#define arch_cache2_size ARCH_CACHE2_SIZE
 #define arch_is_big_endian ARCH_IS_BIG_ENDIAN
-#define arch_ptrs_are_signed ARCH_PTRS_ARE_SIGNED
-#define arch_floats_are_IEEE ARCH_FLOATS_ARE_IEEE
 #define arch_arith_rshift ARCH_ARITH_RSHIFT
 #define arch_can_shift_full_long ARCH_CAN_SHIFT_FULL_LONG
+/*
+ * Define the alignment that the memory manager must preserve.
+ * We assume all alignment moduli are powers of 2.
+ * NOTE: we require that malloc align blocks at least this strictly.
+ */
+#define ARCH_ALIGN_MEMORY_MOD\
+  (((ARCH_ALIGN_LONG_MOD - 1) | (ARCH_ALIGN_PTR_MOD - 1) |\
+    (ARCH_ALIGN_DOUBLE_MOD - 1)) + 1)
 
 /* Define integer data type sizes in terms of log2s. */
+#define ARCH_SIZEOF_CHAR (1 << ARCH_LOG2_SIZEOF_CHAR)
 #define ARCH_SIZEOF_SHORT (1 << ARCH_LOG2_SIZEOF_SHORT)
 #define ARCH_SIZEOF_INT (1 << ARCH_LOG2_SIZEOF_INT)
 #define ARCH_SIZEOF_LONG (1 << ARCH_LOG2_SIZEOF_LONG)
+#define ARCH_SIZEOF_LONG_LONG (1 << ARCH_LOG2_SIZEOF_LONG_LONG)
 #define ARCH_INTS_ARE_SHORT (ARCH_SIZEOF_INT == ARCH_SIZEOF_SHORT)
 /* Backward compatibility */
 #define arch_sizeof_short ARCH_SIZEOF_SHORT
 #define arch_sizeof_int ARCH_SIZEOF_INT
 #define arch_sizeof_long ARCH_SIZEOF_LONG
-#define arch_ints_are_short ARCH_INTS_ARE_SHORT
 
 /* Define whether we are on a large- or small-memory machine. */
 /* Currently, we assume small memory and 16-bit ints are synonymous. */
@@ -76,13 +64,13 @@
 
 /* Define unsigned 16- and 32-bit types.  These are needed in */
 /* a surprising number of places that do bit manipulation. */
-#if arch_sizeof_short == 2	/* no plausible alternative! */
+#if ARCH_SIZEOF_SHORT == 2	/* no plausible alternative! */
 typedef ushort bits16;
 #endif
-#if arch_sizeof_int == 4
+#if ARCH_SIZEOF_INT == 4
 typedef uint bits32;
 #else
-# if arch_sizeof_long == 4
+# if ARCH_SIZEOF_LONG == 4
 typedef ulong bits32;
 # endif
 #endif
@@ -106,13 +94,13 @@ typedef ulong bits32;
  * The UTek compiler does special weird things of its own.
  * All the rest (including gcc on all platforms) do the right thing.
  */
-#define max_uchar arch_max_uchar
-#define max_ushort arch_max_ushort
-#define max_uint arch_max_uint
-#define max_ulong arch_max_ulong
+#define max_uchar ARCH_MAX_UCHAR
+#define max_ushort ARCH_MAX_USHORT
+#define max_uint ARCH_MAX_UINT
+#define max_ulong ARCH_MAX_ULONG
 
 /* Minimum and maximum values for pointers. */
-#if arch_ptrs_are_signed
+#if ARCH_PTRS_ARE_SIGNED
 #  define min_ptr min_long
 #  define max_ptr max_long
 #else
@@ -153,6 +141,18 @@ typedef ulong bits32;
  */
 #include <stdio.h>
 
+/*
+ * Not a very good place to define this, but we can't find a better one.
+ */
+#ifndef gs_memory_DEFINED
+#  define gs_memory_DEFINED
+typedef struct gs_memory_s gs_memory_t;
+#endif
+
+#define init_proc(proc)\
+  int proc(gs_memory_t *)
+
+
 /* dpf and epf may be redefined */
 #define dpf errprintf
 #define epf errprintf
@@ -160,16 +160,26 @@ typedef ulong bits32;
 /* To allow stdout and stderr to be redirected, all stdout goes 
  * though outwrite and all stderr goes through errwrite.
  */
-int outwrite(P2(const char *str, int len));
-int errwrite(P2(const char *str, int len));
-void outflush(P0());
-void errflush(P0());
+
+int outwrite(const gs_memory_t *mem, const char *str, int len);
+int errwrite(const char *str, int len);
+void outflush(const gs_memory_t *mem);
+void errflush(void);
 /* Formatted output to outwrite and errwrite.
  * The maximum string length is 1023 characters.
  */
 #ifdef __PROTOTYPES__
-int outprintf(const char *fmt, ...);
-int errprintf(const char *fmt, ...);
+#  ifndef __printflike
+   /* error checking for printf format args gcc only */
+#    if __GNUC__ > 2 || __GNUC__ == 2 && __GNUC_MINOR__ >= 7
+#      define __printflike(fmtarg, firstvararg) \
+             __attribute__((__format__ (__printf__, fmtarg, firstvararg)))
+#    else
+#      define __printflike(fmtarg, firstvararg)
+#    endif
+#  endif
+int outprintf(const gs_memory_t *mem, const char *fmt, ...) __printflike(2, 3);
+int errprintf(const char *fmt, ...) __printflike(1, 2);
 #else
 int outprintf();
 int errprintf();
@@ -177,14 +187,14 @@ int errprintf();
 
 /* Print the program line # for debugging. */
 #if __LINE__			/* compiler provides it */
-void dprintf_file_and_line(P2(const char *, int));
+void dprintf_file_and_line(const char *, int);
 #  define _dpl dprintf_file_and_line(__FILE__, __LINE__),
 #else
-void dprintf_file_only(P1(const char *));
+void dprintf_file_only(const char *);
 #  define _dpl dprintf_file_only(__FILE__),
 #endif
 
-void dflush(P0());		/* flush stderr */
+void dflush(void);		/* flush stderr */
 #define dputc(chr) dprintf1("%c", chr)
 #define dlputc(chr) dlprintf1("%c", chr)
 #define dputs(str) dprintf1("%s", str)
@@ -242,12 +252,10 @@ void dflush(P0());		/* flush stderr */
 #define dlprintf12(str,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8,arg9,arg10,arg11,arg12)\
   (_dpl dprintf12(str, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg12))
 
-void printf_program_ident(P2(const char *program_name,
-			     long revision_number));
-void eprintf_program_ident(P2(const char *program_name,
-			      long revision_number));
-const char *gs_program_name(P0());
-long gs_revision_number(P0());
+void printf_program_ident(const gs_memory_t *mem, const char *program_name, long revision_number);
+void eprintf_program_ident(const char *program_name, long revision_number);
+const char *gs_program_name(void);
+long gs_revision_number(void);
 
 #define _epi eprintf_program_ident(gs_program_name(), gs_revision_number()),
 
@@ -275,10 +283,10 @@ long gs_revision_number(P0());
   (_epi epf(str, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10))
 
 #if __LINE__			/* compiler provides it */
-void lprintf_file_and_line(P2(const char *, int));
+void lprintf_file_and_line(const char *, int);
 #  define _epl _epi lprintf_file_and_line(__FILE__, __LINE__),
 #else
-void lprintf_file_only(P1(const char *));
+void lprintf_file_only(const char *);
 #  define _epl _epi lprintf_file_only(__FILE__)
 #endif
 
@@ -314,6 +322,6 @@ void lprintf_file_only(P1(const char *));
 typedef struct gs_memory_s gs_memory_t;
 #endif
 #define init_proc(proc)\
-  int proc(P1(gs_memory_t *))
+  int proc(gs_memory_t *)
 
 #endif /* std_INCLUDED */
