@@ -1,22 +1,17 @@
-/* Copyright (C) 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zchar32.c,v 1.2.6.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: zchar32.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Type 32 font glyph operators */
 #include "ghost.h"
 #include "oper.h"
@@ -116,7 +111,7 @@ typedef struct {
     gs_font *font;
 } font_cid_range_t;
 private bool
-select_cid_range(cached_char * cc, void *range_ptr)
+select_cid_range(const gs_memory_t *mem, cached_char * cc, void *range_ptr)
 {
     const font_cid_range_t *range = range_ptr;
 
