@@ -1,22 +1,17 @@
-/* Copyright (C) 1990, 1996, 1997, 1998, 1999, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zdps1.c,v 1.3.4.1.2.1 2003/01/17 00:49:05 giles Exp $ */
+/* $Id: zdps1.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Level 2 / Display PostScript graphics extensions */
 #include "ghost.h"
 #include "oper.h"
@@ -32,7 +27,10 @@
 #include "ibnum.h"
 
 /* Forward references */
-private int gstate_unshare(P1(i_ctx_t *));
+private int gstate_unshare(i_ctx_t *);
+
+/* Declare exported procedures (for zupath.c) */
+int zsetbbox(i_ctx_t *);
 
 /* Structure descriptors */
 public_st_igstate_obj();
@@ -243,8 +241,8 @@ typedef struct local_rects_s {
 } local_rects_t;
 
 /* Forward references */
-private int rect_get(P3(local_rects_t *, os_ptr, gs_memory_t *));
-private void rect_release(P2(local_rects_t *, gs_memory_t *));
+private int rect_get(local_rects_t *, os_ptr, gs_memory_t *);
+private void rect_release(local_rects_t *, gs_memory_t *);
 
 /* <x> <y> <width> <height> .rectappend - */
 /* <numarray|numstring> .rectappend - */
@@ -316,7 +314,7 @@ zrectstroke(i_ctx_t *i_ctx_p)
     local_rects_t lr;
     int npop, code;
 
-    if (read_matrix(op, &mat) >= 0) {
+    if (read_matrix(imemory, op, &mat) >= 0) {
 	/* Concatenate the matrix to the CTM just before stroking the path. */
 	npop = rect_get(&lr, op - 1, imemory);
 	if (npop < 0)
@@ -388,7 +386,7 @@ rect_get(local_rects_t * plr, os_ptr op, gs_memory_t *mem)
 	int i;
 
 	for (i = 0; i < 4; i++) {
-	    code = num_array_get((const ref *)op, format,
+	    code = num_array_get(mem, (const ref *)op, format,
 				 (n << 2) + i, &rnum);
 	    switch (code) {
 		case t_integer:
