@@ -1,29 +1,24 @@
-/* Copyright (C) 1994, 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfdcte.c,v 1.5.2.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: zfdcte.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* DCTEncode filter creation */
 #include "memory_.h"
 #include "stdio_.h"		/* for jpeglib.h */
 #include "jpeglib_.h"
 #include "ghost.h"
 #include "oper.h"
-#include "gsmalloc.h"		/* for gs_memory_default */
+#include "gsmemory.h"
 #include "ialloc.h"
 #include "idict.h"
 #include "idparam.h"
@@ -45,7 +40,7 @@ private int
 zDCTE(i_ctx_t *i_ctx_p)
 {
     os_ptr op = osp;
-    gs_memory_t *mem = &gs_memory_default;
+    gs_memory_t *mem = gs_memory_stable(imemory);
     stream_DCT_state state;
     dict_param_list list;
     jpeg_compress_data *jcdp;
