@@ -1,20 +1,17 @@
-/* Copyright (C) 1994, 1995, 1997, 1998, 1999, 2001 Aladdin Enterprises.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This software is provided AS-IS with no warranty, either express or
-  implied.
-  
-  This software is distributed under license and may not be copied,
-  modified or distributed except as expressly authorized under the terms
-  of the license contained in the file LICENSE in this distribution.
-  
-  For more information about licensing, please refer to
-  http://www.ghostscript.com/licensing/. For information on
-  commercial licensing, go to http://www.artifex.com/licensing/ or
-  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
-  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
+
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: zfproc.c,v 1.9.2.1 2002/02/22 19:46:00 ray Exp $ */
+/* $Id: zfproc.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* Procedure-based filter stream support */
 #include "memory_.h"
 #include "ghost.h"
@@ -128,7 +125,7 @@ s_proc_set_defaults(stream_state * st)
 
 /* Forward references */
 private stream_proc_process(s_proc_read_process);
-private int s_proc_read_continue(P1(i_ctx_t *));
+private int s_proc_read_continue(i_ctx_t *);
 
 /* Stream templates */
 private const stream_template s_proc_read_template = {
@@ -248,7 +245,7 @@ s_proc_read_continue(i_ctx_t *i_ctx_p)
 /* Forward references */
 private stream_proc_flush(s_proc_write_flush);
 private stream_proc_process(s_proc_write_process);
-private int s_proc_write_continue(P1(i_ctx_t *));
+private int s_proc_write_continue(i_ctx_t *);
 
 /* Stream templates */
 private const stream_template s_proc_write_template = {
@@ -279,7 +276,8 @@ s_proc_write_process(stream_state * st, stream_cursor_read * pr,
     stream_proc_state *const ss = (stream_proc_state *) st;
     uint rcount = pr->limit - pr->ptr;
 
-    if (rcount > 0) {
+    /* if 'last' return CALLC even when rcount == 0. ss->eof terminates */
+    if (rcount > 0 || (last && !ss->eof)) {
 	uint wcount = r_size(&ss->data) - ss->index;
 	uint count = min(rcount, wcount);
 
