@@ -1,22 +1,17 @@
-/* Copyright (C) 2000 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 artofcode LLC.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: ziodevs.c,v 1.5.2.1.2.1 2003/01/17 00:49:06 giles Exp $ */
+/* $Id: ziodevs.c 6651 2006-03-13 16:18:19Z stefan $ */
 /* %stdxxx IODevice implementation for PostScript interpreter */
 #include "stdio_.h"
 #include "ghost.h"
@@ -49,21 +44,18 @@ const char iodev_dtype_stdio[] = "Special";
  */
 
 #define STDIN_BUF_SIZE 128
-/*#define ref_stdin ref_stdio[0] *//* in files.h */
-bool gs_stdin_is_interactive;	/* exported for command line only */
+
 private iodev_proc_init(stdin_init);
 private iodev_proc_open_device(stdin_open);
 const gx_io_device gs_iodev_stdin =
     iodev_special("%stdin%", stdin_init, stdin_open);
 
 #define STDOUT_BUF_SIZE 128
-/*#define ref_stdout ref_stdio[1] *//* in files.h */
 private iodev_proc_open_device(stdout_open);
 const gx_io_device gs_iodev_stdout =
     iodev_special("%stdout%", iodev_no_init, stdout_open);
 
 #define STDERR_BUF_SIZE 128
-/*#define ref_stderr ref_stdio[2] *//* in files.h */
 private iodev_proc_open_device(stderr_open);
 const gx_io_device gs_iodev_stderr =
     iodev_special("%stderr%", iodev_no_init, stderr_open);
@@ -78,13 +70,13 @@ const gx_io_device gs_iodev_stderr =
  */
 
 private int
-    s_stdin_read_process(P4(stream_state *, stream_cursor_read *,
-			    stream_cursor_write *, bool));
+    s_stdin_read_process(stream_state *, stream_cursor_read *,
+			 stream_cursor_write *, bool);
 
 private int
 stdin_init(gx_io_device * iodev, gs_memory_t * mem)
 {
-    gs_stdin_is_interactive = true;
+    mem->gs_lib_ctx->stdin_is_interactive = true;
     return 0;
 }
 
@@ -101,7 +93,7 @@ s_stdin_read_process(stream_state * st, stream_cursor_read * ignore_pr,
     if (wcount <= 0)
 	return 0;
     count = gp_stdin_read( (char*) pw->ptr + 1, wcount,
-			   gs_stdin_is_interactive, file);
+			   st->memory->gs_lib_ctx->stdin_is_interactive, file);
     pw->ptr += (count < 0) ? 0 : count;
     return ((count < 0) ? ERRC : (count == 0) ? EOFC : count);
 }
